import aiohttp
from typing import Union, List


class TelemetryAsync:
    def __init__(self):
        self.api_key = None
        self.base_url = "https://api.telemetry.sh"

    def init(self, api_key: str):
        self.api_key = api_key
        
    async def check_and_return(self, response: aiohttp.ClientResponse) -> dict:
        respose_json = await response.json()
        if respose_json.get("status", "error") == "error":
            raise Exception(respose_json.get("message", "Unknown error"))
        return respose_json

    async def log(self, table: str, data: Union[dict, List[dict]]) -> dict:
        if not self.api_key:
            raise ValueError(
                "API key is not initialized. Please call init() with your API key."
            )

        headers = {"Content-Type": "application/json", "Authorization": self.api_key}

        body = {"data": data, "table": table}

        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.base_url}/log", headers=headers, json=body
            ) as response:
                return await self.check_and_return(response)

    async def query(self, query: str) -> dict:
        if not self.api_key:
            raise ValueError(
                "API key is not initialized. Please call init() with your API key."
            )

        headers = {"Content-Type": "application/json", "Authorization": self.api_key}

        body = {"query": query, "realtime": True, "json": True}

        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.base_url}/query", headers=headers, json=body
            ) as response:
                return await self.check_and_return(response)



import requests
import json
from typing import Union, List

class Telemetry:
    def __init__(self):
        self.api_key = None
        self.base_url = "https://api.telemetry.sh"

    def init(self, api_key: str):
        self.api_key = api_key
        
    def check_and_return(self, response: requests.Response) -> dict:
        response_json = response.json()
        if response_json.get("status", "error") == "error":
            raise Exception(response_json.get("message", "Unknown error"))
        return response_json

    def log(self, table: str, data: Union[dict, List[dict]]) -> dict:
        if not self.api_key:
            raise ValueError("API key is not initialized. Please call init() with your API key.")
        
        headers = {
            "Content-Type": "application/json",
            "Authorization": self.api_key
        }
        
        body = {
            "data": data,
            "table": table
        }
        
        response = requests.post(f"{self.base_url}/log", headers=headers, data=json.dumps(body))
        return self.check_and_return(response)

    def query(self, query: str) -> dict:
        if not self.api_key:
            raise ValueError("API key is not initialized. Please call init() with your API key.")
        
        headers = {
            "Content-Type": "application/json",
            "Authorization": self.api_key
        }
        
        body = {
            "query": query,
            "realtime": True,
            "json": True
        }
        
        response = requests.post(f"{self.base_url}/query", headers=headers, data=json.dumps(body))
        return self.check_and_return(response)

telemetry = Telemetry()



from setuptools import setup, find_packages

setup(
    name="telemetry-sh",
    version="1.0.9",
    description="A simple telemetry logging SDK for Python.",
    author="JR R",
    author_email="thebuilderjr93@gmail.com",
    url="https://github.com/telemetry-sh/telemetry-python",
    packages=find_packages(),
    install_requires=[
        "requests",
        "aiohttp",
        "async_timeout"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
